package com.tencent.flutter_integration;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import java.util.HashMap;

import io.flutter.embedding.android.FlutterFragment;
import io.flutter.embedding.android.FlutterView;
import io.flutter.embedding.engine.FlutterEngine;

public class FlutterIntegrationFragment extends FlutterFragment {

    public String routeName;
    public Object params;
    private FlutterIntegrationEngineContainer mContainer;
    private String mPageId;

    public FlutterIntegrationFragment() {
        super();
        mContainer = FlutterIntegrationManager.sharedInstance().container;
    }

    public static FlutterIntegrationFragment newInstance(String routeName) {
        return newInstance(routeName, null);
    }

    public static FlutterIntegrationFragment newInstance(String routeName, Object params) {
        FlutterIntegrationFragment fragment =
                new NewEngineFragmentBuilder(FlutterIntegrationFragment.class).initialRoute("/").transparencyMode(FlutterView.TransparencyMode.opaque)
                        .build();
        fragment.routeName = routeName;
        fragment.params = params;

        return fragment;
    }

    @Override
    public FlutterEngine provideFlutterEngine(Context context) {
        return mContainer.flutterEngine;
    }

    @Override
    public void onResume() {
        super.onResume();
        openPage();
        Log.e("FlutterIntegration", String.format("onResume, pageId:%s", mPageId));
    }

    @Override
    public void onPause() {
        Log.e("FlutterIntegration", String.format("onDestroyView, pageId:%s", mPageId));
        removePage();
        super.onPause();
    }

    @Override
    public void onDetach() {
        super.onDetach();
    }

    @Override
    public boolean shouldDestroyEngineWithHost() {
        return false;
    }

    @SuppressLint("DefaultLocale")
    private String getPageId() {
        if (mPageId == null || mPageId.length() <= 0) {
            mPageId = String.format("%s_%d", routeName, System.currentTimeMillis());
        }
        return mPageId;
    }

    private void openPage() {
        HashMap<String, Object> map = new HashMap<>();
        map.put("routeName", routeName);
        map.put("pageId", getPageId());
        if (params != null) {
            map.put("params", params);
        }

        mContainer.methodChannel.invokeMethod("openPage", map);
    }

    private void removePage() {
        HashMap<String, Object> map = new HashMap<>();
        map.put("pageId", mPageId);

        mContainer.methodChannel.invokeMethod("removePage", map);
    }
}
